@@ -23,7 +23,7 @@ from .utils import (
     SelectResult, awaitable, bind_socket, cancel_tasks, chunk_list,
     new_event_loop, select, shield,
 )
-
+from .worker_pool.pool import WorkerPool
 
 plugins = {
     entry_point.name: entry_point.load()
@@ -81,4 +81,5 @@ __all__ = (
     "threaded_separate",
     "ThreadPoolExecutor",
     "timeout",
+    "WorkerPool",
 )
