@@ -1,28 +1,29 @@
+import asyncio
 import inspect
 import logging
 import socket
+import typing as t
 from types import MappingProxyType
-from typing import Iterable, Mapping  # NOQA
 
 import yarl
 from aiohttp import ClientSession, TCPConnector
+from raven import Client  # type: ignore
+from raven.handlers.logging import SentryHandler  # type: ignore
+from raven.transport import Transport  # type: ignore
+from raven_aiohttp import QueuedAioHttpTransport  # type: ignore
 
 from aiomisc.service import Service
-from raven import Client
-from raven.handlers.logging import SentryHandler
-from raven.transport import Transport
-from raven_aiohttp import QueuedAioHttpTransport
 
 
 log = logging.getLogger(__name__)
 
 
-class DummyTransport(Transport):
-    def send(self, url, data, headers):
+class DummyTransport(Transport):         # type: ignore
+    def send(self, url, data, headers):  # type: ignore
         pass
 
 
-class QueuedKeepaliveAioHttpTransport(QueuedAioHttpTransport):
+class QueuedKeepaliveAioHttpTransport(QueuedAioHttpTransport):  # type: ignore
     DNS_CACHE_TTL = 600
     DNS_CACHE = True
     TCP_CONNECTION_LIMIT = 32
@@ -31,12 +32,13 @@ class QueuedKeepaliveAioHttpTransport(QueuedAioHttpTransport):
     QUEUE_SIZE = 1000
 
     def __init__(
-        self, *args, family=socket.AF_UNSPEC, loop=None,
+        self, *args: t.Any, family: int = socket.AF_UNSPEC,
+        loop: asyncio.AbstractEventLoop = None,
         dns_cache: bool = DNS_CACHE,
         dns_cache_ttl: int = DNS_CACHE_TTL,
         connection_limit: int = TCP_CONNECTION_LIMIT,
         connection_limit_host: int = TCP_CONNECTION_LIMIT_HOST,
-        workers: int = WORKERS, qsize: int = QUEUE_SIZE, **kwargs
+        workers: int = WORKERS, qsize: int = QUEUE_SIZE, **kwargs: t.Any
     ):
         self.connection_limit = connection_limit
         self.connection_limit_host = connection_limit_host
@@ -48,7 +50,7 @@ class QueuedKeepaliveAioHttpTransport(QueuedAioHttpTransport):
             workers=workers, qsize=qsize, **kwargs
         )
 
-    def _client_session_factory(self):
+    def _client_session_factory(self) -> ClientSession:
         self.connector = TCPConnector(
             family=self.family,
             limit=self.connection_limit,
@@ -63,7 +65,7 @@ class QueuedKeepaliveAioHttpTransport(QueuedAioHttpTransport):
             connector_owner=False,
         )
 
-    async def _close(self):
+    async def _close(self) -> Transport:
         transport = await super()._close()
         if inspect.iscoroutinefunction(self.connector.close()):
             await self.connection.close()
@@ -77,13 +79,13 @@ class RavenSender(Service):
 
     sentry_dsn = None  # type: yarl.URL
     min_level = logging.WARNING  # type: int
-    client_options = MappingProxyType({})  # type: Mapping
+    client_options = MappingProxyType({})  # type: t.Mapping
 
     client = None  # type: Client
 
-    filters = ()  # type: Iterable[logging.Filter]
+    filters = ()  # type: t.Iterable[logging.Filter]
 
-    async def start(self):
+    async def start(self) -> None:
         self.client = Client(
             str(self.sentry_dsn),
             transport=QueuedKeepaliveAioHttpTransport,
@@ -112,7 +114,7 @@ class RavenSender(Service):
             handler,
         )
 
-    async def stop(self, *_):
+    async def stop(self, *_: t.Any) -> None:
         transport = self.client.remote.get_transport()
         self.client.set_dsn("", transport=DummyTransport)
 
