@@ -2,6 +2,7 @@ import asyncio
 import logging
 import os
 import socket
+import sys
 import typing as t
 from asyncio.events import get_event_loop
 from contextlib import contextmanager, suppress
@@ -11,7 +12,7 @@ from unittest.mock import MagicMock
 import pytest
 
 import aiomisc
-
+from aiomisc.log.config import LOG_LEVEL
 
 log = logging.getLogger("aiomisc_pytest")
 asyncio.get_event_loop = MagicMock(asyncio.get_event_loop)
@@ -157,6 +158,16 @@ class TCPProxyClient:
             self.__client_repr, self.__server_repr,
         )
 
+    if sys.version_info < (3, 7):
+        @staticmethod
+        async def _close_writer(writer: asyncio.StreamWriter):
+            writer.close()
+    else:
+        @staticmethod
+        async def _close_writer(writer: asyncio.StreamWriter):
+            writer.close()
+            await writer.wait_closed()
+
     async def pipe(
         self, reader: asyncio.StreamReader,
         writer: asyncio.StreamWriter,
@@ -180,8 +191,7 @@ class TCPProxyClient:
                 if not self.buffered:
                     await writer.drain()
         finally:
-            writer.close()
-            await writer.wait_closed()
+            await self._close_writer(writer)
 
     async def connect(self, target_host: str, target_port: int) -> None:
         log.debug("Establishing connection for %r", self)
@@ -592,6 +602,9 @@ def loop(
     from aiomisc.context import get_context
     from aiomisc.entrypoint import entrypoint
 
+    if LOG_LEVEL:
+        LOG_LEVEL.set(logging.getLogger().getEffectiveLevel())
+
     pool = thread_pool_executor(thread_pool_size)
     loop.set_default_executor(pool)
 
